// #include "Program.h"
// Program* program;

// void setup() {
//     program = new Program();
// }

// void loop() {
//     program->loop();
// }

#include <Arduino.h>

#include <M5Stack.h>
#include "Module_GRBL_13.2.h"


#define STEPMOTOR_I2C_ADDR 0x70
// #define STEPMOTOR_I2C_ADDR 0x71

Module_GRBL _GRBL = Module_GRBL(STEPMOTOR_I2C_ADDR);

/**
 * @brief initialise le GRBL pour le stepper
 *
 * @param speed vitesse par defaut du moteur
 * @param pas nombre de pas par mm du moteur
 * @param accel vitesse d'acceleration du mptuer (mm/sec²)
 * @param mode mode de fonctionnement (defaut = distance) absolute
 */
void init(int speed, double pas, int accel ,String mode = "distance"){
    char s[1024];

    _GRBL.Init(&Wire);
    _GRBL.setMode(mode);

    sprintf(s,"$0=%f", pas);  // step/mm
    _GRBL.sendGcode(s);
    Serial.println(s);

    sprintf(s,"$4=%d", speed);  // speed
    _GRBL.sendGcode(s);
    Serial.println(s);

    sprintf(s,"$8=%d", accel);  // acceleration, mm/sec^2
    _GRBL.sendGcode(s);
    Serial.println(s);

    sprintf(s,"$3=%d", 500);  // puse/µsec
    _GRBL.sendGcode(s);
    Serial.println(s);
}

void setup() {
    M5.begin();
    M5.Power.begin();
    Wire.begin(21, 22);
    Serial.begin(115200);
    M5.Lcd.setTextColor(WHITE, BLACK);
    M5.Lcd.setTextSize(3);
    M5.lcd.setBrightness(100);
    M5.Lcd.setCursor(80, 40);
    M5.Lcd.println("GRBL 13.2");
    M5.Lcd.setCursor(50, 80);
    M5.Lcd.println("Press Btn A/B");
    M5.Lcd.setCursor(50, 120);
    delay(1000);
    M5.Lcd.println("Control Motor");
    init(STEPER_SPEED, STEPER_PAS, STEPER_ACC);
}

void mouveForward(int mm = 5){
    char s[1024];
    sprintf(s, "G1 X%d", mm);
    _GRBL.sendGcode(s);
}

void loop() {
    if (M5.BtnA.wasPressed())
    {
        Serial.print(_GRBL.readStatus());
        mouveForward(50);
    }

    if (M5.BtnB.wasPressed()) {
        mouveForward(50);
    }

    if (M5.BtnC.wasReleased()) {
        _GRBL.unLock();
    }
    M5.update();
}
